

set -ex



test -f "$PREFIX/include/rhash.h"
test -f "$PREFIX/lib/librhash.a"
test -f "$PREFIX/lib/librhash.0.dylib"
test -e "$PREFIX/lib/librhash${SHLIB_EXT}"
rhash --version
tests/test_rhash.sh
exit 0
